# Grinder-Smartling
![Runtime](https://img.shields.io/badge/dart-%3E%3D1.23-brightgreen.svg) ![Release](https://img.shields.io/pub/v/grinder_smartling.svg) ![License](https://img.shields.io/badge/license-Apache--2.0-blue.svg) ![Coverage](https://coveralls.io/repos/github/cedx/grinder-smartling/badge.svg) ![Build](https://travis-ci.org/cedx/grinder-smartling.svg)

[Grinder](https://google.github.io/grinder.dart) plug-in dedicated to the synchronization of translations with the [Smartling](https://www.smartling.com) service, based on the [File API v2](http://docs.smartling.com/pages/API/v2).

## Getting started
If you haven't used [Grinder](https://github.com/google/grinder.dart) before, be sure to check out the [related documentation](https://google.github.io/grinder.dart), as it explains how to create a `grind.dart` file and to define project tasks. Once you're familiar with that process, you may install this plug-in.

## Installing via [Pub](https://pub.dartlang.org)

### 1. Depend on it
Add this to your package's `pubspec.yaml` file:

```yaml
devDpendencies:
  grinder_smartling: *
```

### 2. Install it
Install this package and its dependencies from a command prompt:

```shell
$ pub get
```

Once the plug-in has been installed, it may be enabled inside your `grind.dart` file.

## Usage
The plug-in lets you synchronize translations with the [Smartling](https://www.smartling.com) service.
Two functions are dedicated to this feature:

- `download()`: Downloads the message translations from the remote server.
- `upload()`: Uploads the source messages to the remote server.

These functions require four named parameters:

- `String fileUri` : A value that uniquely identifies the remote file.
- `String projectId` : The project identifier.
- `String userId` : The identifier used to identify the API user.
- `String userSecret` : The secret used to authenticate the API user.

### Download the message translations from the Smartling service
The `download()` function takes a file pattern and a list of locales as inputs, indicating the path of the downloaded files and their target language.
The `{{locale}}` placeholder will be replaced by the locale of each file.

```dart
import 'dart:async';
import 'package:grinder/grinder.dart';
import 'package:grinder_smartling/grinder_smartling.dart' as smartling;

@Task('Download the message translations from the Smartling service')
Future i18nDownload() => smartling.download(
  'path/to/i18n/{{locale}}.json', ['es-ES', 'fr-FR', 'ja-JP'],
  fileUri: '/Gulp-Smartling/messages.json',
  projectId: 'FooBar',
  userId: 'john.doe',
  userSecret: 'MyPassword'
);
```

The supported options are:

- `bool includeOriginalStrings = false` : A value indicating whether to return the original string when no translation is available.
- `String retrievalType = "published"` : The desired format for the download.

### Upload the message source to the Smartling service
The `upload()` function takes a file path as input, specifying the message source to be uploaded.

```dart
import 'dart:async';
import 'package:grinder/grinder.dart';
import 'package:grinder_smartling/grinder_smartling.dart' as smartling;

@Task('Upload the source messages to the Smartling service')
Future i18nUpload() => smartling.upload(
  'path/to/i18n/en-US.json',
  fileUri: '/Gulp-Smartling/messages.json',
  projectId: 'FooBar',
  userId: 'john.doe',
  userSecret: 'MyPassword'
);
```

The supported options are:

- `bool authorize = false` : A value indicating whether content in the file is authorized in all locales.
- `dynamic callbackUrl = null` : The URL of the callback called when the file is 100% published for a locale.
- `String fileType = ""` : The file type. If empty, will be guessed from the extension of the input file.

## See also
- [API reference](https://cedx.github.io/grinder-smartling)
- [Code coverage](https://coveralls.io/github/cedx/grinder-smartling)
- [Continuous integration](https://travis-ci.org/cedx/grinder-smartling)

## License
[Grinder-Smartling](https://github.com/cedx/grinder-smartling) is distributed under the Apache License, version 2.0.
