part of grinder_smartling;

/// Represents a locale, that is a language-region pair.
class Locale {

  /// Provides the mapping between neutral locales and default specific locales.
  static final Map<String, String> _locales = const {
    'af': 'af-ZA', 'az': 'az-AZ',
    'be': 'be-BY', 'bg': 'bg-BG', 'bs': 'bs-BA',
    'cs': 'cs-CZ',
    'da': 'da-DK', 'de': 'de-DE',
    'el': 'el-GR', 'en': 'en-US', 'es': 'es-ES', 'et': 'et-EE',
    'fi': 'fi-FI', 'fo': 'fo-FO', 'fr': 'fr-FR',
    'he': 'he-IL', 'hi': 'hi-IN', 'hr': 'hr-HR', 'hu': 'hu-HU', 'hy': 'hy-AM',
    'id': 'id-ID', 'is': 'is-IS', 'it': 'it-IT',
    'ja': 'ja-JP',
    'ka': 'ka-GE', 'kk': 'kk-KZ', 'kl': 'kl-GL', 'km': 'km-KH', 'ko': 'ko-KR', 'ky': 'ky-KG',
    'lb': 'lb-LU', 'lt': 'lt-LT', 'lv': 'lv-LV',
    'mk': 'mk-MK', 'mn': 'mn-MN', 'ms': 'ms-MY',
    'ne': 'ne-NP', 'nl': 'nl-NL', 'nn': 'nn-NO',
    'pl': 'pl-PL', 'ps': 'ps-AF', 'pt': 'pt-BR',
    'qu': 'qu-PE',
    'ro': 'ro-RO', 'ru': 'ru-RU',
    'sk': 'sk-SK', 'sl': 'sl-SI', 'sq': 'sq-AL', 'sr': 'sr-RS', 'sv': 'sv-SE', 'sw': 'sw-KE',
    'tg': 'tg-TJ', 'th': 'th-TH', 'tk': 'tk-TM', 'tr': 'tr-TR',
    'uk': 'uk-UA', 'uz': 'uz-UZ',
    'vi': 'vi-VN',
    'zh': 'zh-CN'
  };

  /// Creates a new locale.
  Locale([String locale = '']) {
    assert(locale != null);

    var parts = locale.split(new RegExp('[-_]'));
    assert(parts.length <= 2);

    language = parts.first.toLowerCase();
    region = parts.length > 1 ? parts.last.toUpperCase() : '';
  }

  /// The ISO 639-1 two-letter code for the language.
  String language;

  /// The ISO 3166 two-letter code for the country/region.
  String region;

  /// The default specific locale corresponding to this neutral locale.
  /// Returns this locale if no specific locale matches or if it is already specific.
  Locale get specificLocale {
    if (region.isNotEmpty) return this;
    return _locales.containsKey(language) ? new Locale(_locales[language]) : this;
  }

  /// Converts this object to a map in JSON format.
  Map<String, dynamic> toJson() => {
    'language': language,
    'region': region
  };

  /// Returns a string representation of this object.
  @override
  String toString() => region.isEmpty ? language : '$language-$region';
}
