part of grinder_smartling;

/// Provides common properties and methods for the [Grinder](https://google.github.io/grinder.dart) tasks
/// dedicated to the [Smartling](https://www.smartling.com) service.
abstract class Task {

  /// Creates a new task.
  Task([this.projectId = '', String userId = '', String userSecret = '']):
    client = new Client(userId, userSecret);

  /// The underlying HTTP client used to query the Smartling service.
  final Client client;

  /// The project identifier.
  String projectId;

  /// The user identifier.
  String get userId => client.userId;
  set userId(String value) => client.userId = value;

  /// The user secret.
  String get userSecret => client.userSecret;
  set userSecret(String value) => client.userSecret = value;

  /// Validates the requirements.
  /// Throws a [ArgumentError] if the requirements are not met.
  void validate() {
    if (projectId == null || projectId.isEmpty) throw new ArgumentError('Your must provide the "projectId" option.');
    if (userId == null || userId.isEmpty) throw new ArgumentError('Your must provide the "userId" option.');
    if (userSecret == null || userSecret.isEmpty) throw new ArgumentError('Your must provide the "userSecret" option.');
  }
}
