part of grinder_smartling;

/// Downloads the message translations from the [Smartling](https://www.smartling.com) server.
class DownloadTask extends FileTask {

  /// Creates a new download task.
  DownloadTask([String fileUri = '', String projectId = '', String userId = '', String userSecret = '']):
    super(fileUri, projectId, userId, userSecret);

  /// The pattern indicating the target path of the downloaded files (e.g. `path/to/i18n/{{locale}}.json`).
  String filePattern = '';

  /// Value indicating whether to return the original string or an empty string when no translation is available.
  bool includeOriginalStrings = false;

  /// The list of locales to be downloaded.
  final List<Locale> locales = [];

  /// The desired format for the download. Defaults to [RetrievalType.published].
  String retrievalType = RetrievalType.published;

  /// Downloads the message translations from the Smartling server.
  Future run() async {
    validate();

    var params = {
      'includeOriginalStrings': includeOriginalStrings ? 'true' : 'false',
      'retrievalType': retrievalType
    };

    return Future.wait(locales.map((locale) async {
      var output = getFile(filePattern.replaceFirst('{{locale}}', locale.toString()));
      await output.parent.create(recursive: true);
      return output.writeAsBytes(await client.downloadFile(projectId, fileUri, locale.specificLocale, params: params));
    }));
  }

  /// Validates the requirements.
  /// Throws a [ArgumentError] if the requirements are not met.
  @override
  void validate() {
    super.validate();
    if (filePattern == null || filePattern.isEmpty) throw new ArgumentError('You must provide the "filePattern" option.');
    if (locales.isEmpty) throw new ArgumentError('You must specify at least one locale in the "locales" option.');
    if (retrievalType == null || retrievalType.isEmpty) throw new ArgumentError('You must provide the "retrievalType" option.');
  }
}
