part of grinder_smartling;

/// Provides the base implementation for file-based tasks.
abstract class FileTask extends Task {

  /// Creates a new file task.
  FileTask([this.fileUri = '', String projectId = '', String userId = '', String userSecret = '']):
    super(projectId, userId, userSecret);

  /// A value that uniquely identifies the file.
  String fileUri;

  /// Gets the file type corresponding to the specified file URI.
  /// Returns an empty string if the type is unknown.
  static String getFileTypeFromUri(String fileUri) {
    assert(fileUri != null);

    var extension = path.extension(fileUri);
    if (extension.isEmpty) return '';

    extension = extension.substring(1).toLowerCase();
    switch (extension) {
      case FileType.csv:
      case FileType.html:
      case FileType.inDesign:
      case FileType.iosStringsDict:
      case FileType.json:
      case FileType.openXml:
      case FileType.resx:
      case FileType.subrip:
      case FileType.yaml:
        return extension;

      case 'po':
      case 'pot':
        return FileType.gettext;

      case 'pptx':
      case 'xslx':
        return FileType.openXml;

      case 'properties':
        return FileType.javaProperties;

      case 'strings':
        return FileType.iosStrings;

      case 'ts':
        return FileType.qtLinguist;

      case 'txt':
        return FileType.plainText;

      case 'xlf':
        return FileType.xliff;

      case 'yml':
        return FileType.yaml;

      default:
        return '';
    }
  }

  /// Validates the requirements.
  /// Throws a [ArgumentError] if the requirements are not met.
  @override
  void validate() {
    super.validate();
    if (fileUri == null || fileUri.isEmpty) throw new ArgumentError('Your must provide the "fileUri" option.');
  }
}
