part of grinder_smartling;

/// Uploads the message source to the [Smartling](https://www.smartling.com) server.
class UploadTask extends FileTask {

  /// Creates a new upload task.
  UploadTask([String fileUri = '', String projectId = '', String userId = '', String userSecret = '']):
    super(fileUri, projectId, userId, userSecret);

  /// Value indicating whether content in the file is authorized (available for translation) in all locales.
  bool authorize = false;

  /// The URL of the callback called when the file is 100% published for a locale.
  Uri callbackUrl;

  /// The path to the message file.
  File file;

  /// The desired format for the download.
  String fileType = '';

  /// Uploads the original source content to the Smartling server.
  Future run() async {
    validate();

    var params = {
      'authorize': authorize ? 'true' : 'false',
      'fileType': fileType
    };

    if (callbackUrl != null) params['callbackUrl'] = callbackUrl.toString();
    return client.uploadFile(projectId, fileUri, file, params: params);
  }

  /// Validates the requirements.
  /// Throws a [ArgumentError] if the requirements are not met.
  @override
  void validate() {
    super.validate();
    if (file == null) throw new ArgumentError('You must provide the "file" option.');
    if (fileType == null || fileType.isEmpty) fileType = FileTask.getFileTypeFromUri(file.path);
    if (fileType.isEmpty) throw new ArgumentError('You must provide the "fileType" option.');
  }
}
