import 'package:grinder_smartling/grinder_smartling.dart';
import 'package:test/test.dart';

/// Tests the features of the [Locale] class.
void main() => group('Locale', () {
  group('constructor', () {
    test('should set the `language` property', () {
      expect(new Locale().language, isEmpty);
      expect(new Locale('EN').language, equals('en'));
      expect(new Locale('EN-us').language, equals('en'));
      expect(new Locale('fr_FR').language, equals('fr'));
    });

    test('should set the `region` property', () {
      expect(new Locale().region, isEmpty);
      expect(new Locale('EN').region, isEmpty);
      expect(new Locale('EN-us').region, equals('US'));
      expect(new Locale('fr_FR').region, equals('FR'));
    });
  });

  group('.specificLocale', () {
    test('should return the specified value if it is an unknown locale', () {
      var locale = new Locale();
      expect(locale.specificLocale, equals(locale));

      locale = new Locale('fooBar');
      expect(locale.specificLocale, equals(locale));
    });

    test('should return the specified value if it is already a specific locale', () {
      var locale = new Locale('en-GB');
      expect(locale.specificLocale, equals(locale));

      locale = new Locale('FR_be');
      expect(locale.specificLocale, equals(locale));
    });

    test('should return a specific locale if the specified value is a known neutral locale', () {
      var locale = new Locale('en').specificLocale;
      expect(locale.language, equals('en'));
      expect(locale.region, equals('US'));

      locale = new Locale('FR').specificLocale;
      expect(locale.language, equals('fr'));
      expect(locale.region, equals('FR'));
    });
  });

  group('.toJson()', () {
    test('should return a map with default values for a newly created instance', () {
      var data = new Locale().toJson();
      expect(data, allOf(isMap, hasLength(2)));
      expect(data['language'], isEmpty);
      expect(data['region'], isEmpty);
    });

    test('should return a non-empty map for an initialized instance', () {
      var data = new Locale('EN_us').toJson();
      expect(data, allOf(isMap, hasLength(2)));
      expect(data['language'], equals('en'));
      expect(data['region'], equals('US'));
    });
  });

  group('.toString()', () {
    test('should return an empty string for a new instance', () {
      expect(new Locale().toString(), isEmpty);
    });

    test('should return a format like "<language>" for neutral locales', () {
      expect(new Locale('en').toString(), equals('en'));
    });

    test('should return a format like "<language>-<region>" for specific locales', () {
      expect(new Locale('EN_us').toString(), equals('en-US'));
    });
  });
});
