import 'dart:io';
import 'package:grinder/grinder.dart';
import 'package:grinder_smartling/grinder_smartling.dart';
import 'package:test/test.dart';

/// Tests the features of the [DownloadTask] class.
void main() => group('DownloadTask', () {
  group('.run()', () {
    test('should throw an error if the requirements are not met', () {
      expect(new DownloadTask().run(), throwsA(isArgumentError));
    });

    var projectId = Platform.environment['SMARTLING_PROJECT_ID'];
    var userId = Platform.environment['SMARTLING_USER_ID'];
    var userSecret = Platform.environment['SMARTLING_USER_SECRET'];
    if (projectId != null && userId != null && userSecret != null) test('should download the translated file', () async {
      var output = getFile('var/messages.fr.json');
      var task = new DownloadTask('messages.json', projectId, userId, userSecret)
        ..filePattern = 'var/messages.{{locale}}.json'
        ..locales.add(new Locale('fr'));

      task.includeOriginalStrings = false;
      await task.run();
      expect(await output.exists(), isTrue);
      expect(await output.readAsString(), contains('"Foo" : ""'));

      task.includeOriginalStrings = true;
      await task.run();
      expect(await output.exists(), isTrue);
      expect(await output.readAsString(), contains('"Foo" : "Foo"'));
    });
  });

  group('.validate()', () {
    test('should throw an error if the instance is not properly initialized', () {
      expect(() => new DownloadTask().validate(), throwsArgumentError);
      expect(() => new DownloadTask('messages.json', 'FooBar', 'anonymous', 'secret').validate(), throwsArgumentError);
    });

    test('should not throw an error if the instance is properly initialized', () {
      var task = new DownloadTask('messages.json', 'FooBar', 'anonymous', 'secret')
        ..filePattern = 'out/i18n/{{locale}}.json'
        ..locales.add(new Locale('fr'));

      expect(() => task.validate(), returnsNormally);
    });
  });
});
