import 'package:grinder_smartling/grinder_smartling.dart';
import 'package:test/test.dart';

/// The class to be tested.
class _FileTask extends FileTask {
  _FileTask([String fileUri = '', String projectId = '', String userId = '', String userSecret = '']):
    super(fileUri, projectId, userId, userSecret);
}

/// Tests the features of the [FileTask] class.
void main() => group('FileTask', () {
  group('.getFileTypeFromUri()', () {
    test('should return an emtpy string for an unknown file extension', () {
      expect(FileTask.getFileTypeFromUri('/fooBar'), isEmpty);
      expect(FileTask.getFileTypeFromUri('/foo.bar'), isEmpty);
    });

    test('should return the proper type for a known file extension', () {
      expect(FileTask.getFileTypeFromUri('/messages.csv'), equals(FileType.csv));
      expect(FileTask.getFileTypeFromUri('/project/messages.json'), equals(FileType.json));
      expect(FileTask.getFileTypeFromUri('messages.properties'), equals(FileType.javaProperties));
      expect(FileTask.getFileTypeFromUri('project/messages.xlf'), equals(FileType.xliff));
    });
  });

  group('.validate()', () {
    test('should throw an error if the instance is not properly initialized', () {
      expect(() => new _FileTask().validate(), throwsArgumentError);
      expect(() => new _FileTask('messages.json').validate(), throwsArgumentError);
    });

    test('should not throw an error if the instance is properly initialized', () {
      expect(() => new _FileTask('messages.json', 'FooBar', 'anonymous', 'secret').validate(), returnsNormally);
    });
  });
});
