import 'dart:io';
import 'package:grinder/grinder.dart';
import 'package:grinder_smartling/grinder_smartling.dart';
import 'package:test/test.dart';

/// Tests the features of the [UploadTask] class.
void main() => group('UploadTask', () {
  group('.run()', () {
    test('should throw an error if the requirements are not met', () {
      expect(new UploadTask().run(), throwsA(isArgumentError));
    });

    var projectId = Platform.environment['SMARTLING_PROJECT_ID'];
    var userId = Platform.environment['SMARTLING_USER_ID'];
    var userSecret = Platform.environment['SMARTLING_USER_SECRET'];
    if (projectId != null && userId != null && userSecret != null) test('should upload the source content', () {
      var task = new UploadTask('messages.json', projectId, userId, userSecret)
        ..file = getFile('test/fixtures/messages.json');

      expect(task.run(), completes);
    });
  });

  group('.validate()', () {
    test('should throw an error if the instance is not properly initialized', () {
      expect(() => new UploadTask().validate(), throwsArgumentError);
      expect(() => new UploadTask('messages.json', 'FooBar', 'anonymous', 'secret').validate(), throwsArgumentError);
    });

    test('should not throw an error if the instance is properly initialized', () {
      var task = new UploadTask('messages.json', 'FooBar', 'anonymous', 'secret')
        ..file = getFile('src/i18n/en.json');

      expect(() => task.validate(), returnsNormally);
    });
  });
});
